CREATE SCHEMA `overstock` ;

USE `overstock`;

/* Creating Table SalesOrder*/

CREATE TABLE `overstock`.`salesorder` (
  `SalesOrderID` INT NOT NULL AUTO_INCREMENT,
  `PurchaseOrderType` VARCHAR(45) NULL,
  `SupplierOrderNumber` VARCHAR(45) NULL,
  `RetailerOrderNumber` VARCHAR(45) NULL,
  `OrderDate` DATETIME NULL,
  `WarehouseName` VARCHAR(45) NULL,
  `RetailerName` VARCHAR(45) NULL,
  `CarrierCode` VARCHAR(45) NULL,
  `ShippingName` VARCHAR(45) NULL,
  `ShippingStreet` VARCHAR(75) NULL,
  `ShippingCity` VARCHAR(45) NULL,
  `ShippingState` VARCHAR(45) NULL,
  `ShippingZip` VARCHAR(45) NULL,
  `ShippingCountry` VARCHAR(45) NULL,
  `ShippingPhone` VARCHAR(45) NULL,
  `CustomerName` VARCHAR(45) NULL,
  `BillingStreet` VARCHAR(45) NULL,
  `BillingCity` VARCHAR(45) NULL,
  `BillingState` VARCHAR(45) NULL,
  `BillingZip` VARCHAR(45) NULL,
  `BillingCountry` VARCHAR(45) NULL,
  `CustomerPhone` VARCHAR(45) NULL,
  PRIMARY KEY (`SalesOrderID`));
  
/*Creating Table SalesOrderLineItems*/

CREATE TABLE `overstock`.`salesorderlineitems` (
  `LineItemID` INT NOT NULL AUTO_INCREMENT,
  `SalesOrderID` INT NULL,
  `LineNumber` VARCHAR(45) NULL,
  `SupplierSKU` VARCHAR(45) NULL,
  `RetailerSKU` VARCHAR(45) NULL,
  `QuantityOrdered` INT NULL,
  `UnitPrice` DECIMAL(8,2) NULL,
  `UPCNumber` INT NULL,
  `ISBNNumber` INT NULL,
  `ManufacturerPartNumber` INT NULL,
  `ProductDescription` VARCHAR(45) NULL,
  PRIMARY KEY (`LineItemID`));
  
  
/*Creating Table Invoice*/

CREATE TABLE `overstock`.`invoice` (
  `InvoiceID` INT NOT NULL AUTO_INCREMENT,
  `InvoiceDate` DATETIME NULL,
  `InvoiceNumber` VARCHAR(45) NULL,
  `SupplierOrderNumber` VARCHAR(45) NULL,
  `RetailerOrderNumber` VARCHAR(45) NULL,
  `CurrencyName` VARCHAR(45) NULL,
  `SellerInvoiceNumber` VARCHAR(45) NULL,
  `RetailerInvoiceNumber` VARCHAR(45) NULL,
  `RemittingName` VARCHAR(45) NULL,
  `RemittingStreet` VARCHAR(45) NULL,
  `RemittingCity` VARCHAR(45) NULL,
  `RemittingState` VARCHAR(45) NULL,
  `RemittingZip` VARCHAR(45) NULL,
  `RemittingCountry` VARCHAR(45) NULL,
  `CustomerName` VARCHAR(45) NULL,
  `BillingStreet` VARCHAR(45) NULL,
  `BillingCity` VARCHAR(45) NULL,
  `BillingState` VARCHAR(45) NULL,
  `BillingZip` VARCHAR(45) NULL,
  `BillingCountry` VARCHAR(45) NULL,
  `TermsDueDate` DATETIME NULL,
  `TermsNetDays` INT NULL,
  `DescriptionofTerms` VARCHAR(45) NULL,
  `ShippingDate` DATETIME NULL,
  `Subtotal` DECIMAL(8,2) NULL COMMENT 'Excluding Terms Discount',
  `Total` DECIMAL(8,2) NULL COMMENT 'Including Terms Discount',
  `SACInfo` VARCHAR(45) NULL,
  `SACService` VARCHAR(45) NULL,
  `SACAmount` DECIMAL(8,2) NULL,
  `SACAllowance` VARCHAR(45) NULL,
  `SACDescription` VARCHAR(80) NULL,
  PRIMARY KEY (`InvoiceID`));

/*Creating Table InvoiceLineItems*/

CREATE TABLE `overstock`.`invoicelineitems` (
  `InvoiceLineItemID` INT NOT NULL AUTO_INCREMENT,
  `LineNumber` VARCHAR(45) NULL,
  `QuantityInvoiced` INT NULL,
  `UnitPrice` DECIMAL(8,2) NULL,
  `ProductId` VARCHAR(45) NULL,
  `ProductDescription` VARCHAR(80) NULL,
  `InvoiceID` INT NULL,
  PRIMARY KEY (`InvoiceLineItemID`));
  
/*Creating Table Items*/

CREATE TABLE `overstock`.`items` (
  `ItemID` INT NOT NULL AUTO_INCREMENT,
  `SupplierRef` VARCHAR(45) NULL,
  `InquiryDate` DATETIME NULL,
  `WarehouseName` VARCHAR(45) NULL,
  `SupplierAccountName` VARCHAR(45) NULL,
  `ProductID` VARCHAR(45) NULL,
  `LineNumber` VARCHAR(45) NULL,
  `QuantityAvailable` INT NULL,
  PRIMARY KEY (`ItemID`));
 
/* Creating Table ASNShipment */
CREATE TABLE `overstock`.`asnshipment` (
  `ASNShipmentID` INT NOT NULL AUTO_INCREMENT,
  `PackingSlipNumber` VARCHAR(45) NULL,
  `TransactionSetDate` DATETIME NULL,
  `PackingType` VARCHAR(45) NULL,
  `NumberofUnits` INT NULL,
  `WeightofShipment` DECIMAL(8,2) NULL,
  `ServiceLevelCode` VARCHAR(45) NULL,
  `Warehouse` VARCHAR(45) NULL,
  `RetailerName` VARCHAR(45) NULL,
  `ShippingDate` DATETIME NULL,
  `ShippingName` VARCHAR(45) NULL,
  `ShippingStreet` VARCHAR(45) NULL,
  `ShippingCity` VARCHAR(45) NULL,
  `ShippingState` VARCHAR(45) NULL,
  `ShippingZip` VARCHAR(45) NULL,
  `ShippingCountry` VARCHAR(45) NULL,
  `HLID` VARCHAR(45) NULL,
  `SACAmount` DECIMAL(8,2) NULL,
  `TransportationMethod` VARCHAR(45) NULL,
  PRIMARY KEY (`ASNShipmentID`));
  
/* Creating Table ASNOrder */

CREATE TABLE `overstock`.`asnorder` (
  `ASNOrderID` INT NOT NULL AUTO_INCREMENT,
  `HLID` VARCHAR(45) NULL,
  `HLParentID` VARCHAR(45) NULL,
  `SupplierOrderNumber` VARCHAR(45) NULL,
  `RetailerOrderNumber` VARCHAR(45) NULL,
  `OrderDate` DATETIME NULL,
  `ASNShipmentID` INT NULL,
  PRIMARY KEY (`ASNOrderID`));
  
/* Creating Table ASNPackage */

CREATE TABLE `overstock`.`asnpackage` (
  `ASNPackageID` INT NOT NULL AUTO_INCREMENT,
 `HLID` VARCHAR(45) NULL,
  `HLParentID` VARCHAR(45) NULL,
  `TrackingNumber` VARCHAR(45) NULL,
  `ASNOrderID` INT NULL,
  PRIMARY KEY (`ASNPackageID`));

CREATE TABLE `overstock`.`asnitem` (
  `ASNItemID` INT NOT NULL AUTO_INCREMENT,
  `HLID` VARCHAR(45) NULL,
  `HLParentID` VARCHAR(45) NULL,
  `LineItemID` VARCHAR(45) NULL,
  `SupplierSKUNumber` VARCHAR(45) NULL,
  `QuantityShipped` INT NULL,
  `QuantityOrdered` INT NULL,
  `ASNPackageID` INT NULL,
  PRIMARY KEY (`ASNItemID`));







